@@ -1,6 +1,6 @@
 package XML::XPath::Node::Element;
 
-$VERSION = '1.15';
+$VERSION = '1.16';
 
 use strict; use warnings;
 use vars qw/@ISA/;
@@ -14,14 +14,12 @@ use vars qw/@ISA/;
 use XML::XPath::Node ':node_keys';
 
 sub new {
-    my $class = shift;
-    my ($tag, $prefix) = @_;
+    my ($class, $tag, $prefix) = @_;
 
     my $pos = XML::XPath::Node->nextPos;
-
     my @vals;
     @vals[node_global_pos, node_prefix, node_children, node_name, node_attribs] =
-            ($pos, $prefix, [], $tag, []);
+        ($pos, $prefix, [], $tag, []);
 
     my $self = \@vals;
     bless $self, $class;
@@ -32,10 +30,11 @@ sub getNodeType { ELEMENT_NODE }
 sub isElementNode { 1; }
 
 sub appendChild {
-    my $self = shift;
+    my $self    = shift;
     my $newnode = shift;
+
     if (shift) { # called from internal to XML::XPath
-#    warn "AppendChild $newnode to $self\n";
+        # warn "AppendChild $newnode to $self\n";
         push @{$self->[node_children]}, $newnode;
         $newnode->setParentNode($self);
         $newnode->set_pos($#{$self->[node_children]});
@@ -54,10 +53,7 @@ sub appendChild {
             }
             else {
                 eval {
-                    if ($pos_number ==
-                            $self->findnodes(
-                                'following::node()'
-                                )->get_node(1)->get_global_pos()) {
+                    if ($pos_number == $self->findnodes('following::node()')->get_node(1)->get_global_pos()) {
                         $self->renumber('following::node()', +5);
                     }
                 };
@@ -72,24 +68,21 @@ sub appendChild {
 }
 
 sub removeChild {
-    my $self = shift;
-    my $delnode = shift;
+    my ($self, $delnode) = @_;
 
     my $pos = $delnode->get_pos;
+    # warn "removeChild: $pos\n";
+    # warn "children: ", scalar @{$self->[node_children]}, "\n";
 
-#    warn "removeChild: $pos\n";
-
-#    warn "children: ", scalar @{$self->[node_children]}, "\n";
-
-#    my $node = $self->[node_children][$pos];
-#    warn "child at $pos is: $node\n";
+    # my $node = $self->[node_children][$pos];
+    # warn "child at $pos is: $node\n";
 
     splice @{$self->[node_children]}, $pos, 1;
 
-#    warn "children now: ", scalar @{$self->[node_children]}, "\n";
+    # warn "children now: ", scalar @{$self->[node_children]}, "\n";
 
     for (my $i = $pos; $i < @{$self->[node_children]}; $i++) {
-#        warn "Changing pos of child: $i\n";
+        # warn "Changing pos of child: $i\n";
         $self->[node_children][$i]->set_pos($i);
     }
 
@@ -98,33 +91,36 @@ sub removeChild {
 }
 
 sub appendIdElement {
-    my $self = shift;
-    my ($val, $element) = @_;
-#    warn "Adding '$val' to ID hash\n";
+    my ($self, $val, $element) = @_;
+    # warn "Adding '$val' to ID hash\n";
     $self->[node_ids]{$val} = $element;
 }
 
 sub DESTROY {
     my $self = shift;
-#    warn "DESTROY ELEMENT: ", $self->[node_name], "\n";
-#    warn "DESTROY ROOT\n" unless $self->[node_name];
+    # warn "DESTROY ELEMENT: ", $self->[node_name], "\n";
+    # warn "DESTROY ROOT\n" unless $self->[node_name];
 
     foreach my $kid ($self->getChildNodes) {
         $kid && $kid->del_parent_link;
     }
+
     foreach my $attr ($self->getAttributeNodes) {
         $attr && $attr->del_parent_link;
     }
+
     foreach my $ns ($self->getNamespaceNodes) {
         $ns && $ns->del_parent_link;
     }
-#     $self->[node_children] = undef;
-#     $self->[node_attribs] = undef;
-#     $self->[node_namespaces] = undef;
+
+    # $self->[node_children] = undef;
+    # $self->[node_attribs] = undef;
+    # $self->[node_namespaces] = undef;
 }
 
 sub getName {
     my $self = shift;
+
     $self->[node_name];
 }
 
@@ -134,6 +130,7 @@ sub getTagName {
 
 sub getLocalName {
     my $self = shift;
+
     my $local = $self->[node_name];
     $local =~ s/.*://;
     return $local;
@@ -141,11 +138,13 @@ sub getLocalName {
 
 sub getChildNodes {
     my $self = shift;
+
     return wantarray ? @{$self->[node_children]} : $self->[node_children];
 }
 
 sub getChildNode {
     my $self = shift;
+
     my ($pos) = @_;
     if ($pos < 1 || $pos > @{$self->[node_children]}) {
         return;
@@ -155,19 +154,21 @@ sub getChildNode {
 
 sub getFirstChild {
     my $self = shift;
+
     return unless @{$self->[node_children]};
     return $self->[node_children][0];
 }
 
 sub getLastChild {
     my $self = shift;
+
     return unless @{$self->[node_children]};
     return $self->[node_children][-1];
 }
 
 sub getAttributeNode {
-    my $self = shift;
-    my ($name) = @_;
+    my ($self, $name) = @_;
+
     my $attribs = $self->[node_attribs];
     foreach my $attr (@$attribs) {
         return $attr if $attr->getName eq $name;
@@ -176,6 +177,7 @@ sub getAttributeNode {
 
 sub getAttribute {
     my $self = shift;
+
     my $attr = $self->getAttributeNode(@_);
     if ($attr) {
         return $attr->getValue;
@@ -184,9 +186,11 @@ sub getAttribute {
 
 sub getAttributes {
     my $self = shift;
+
     if ($self->[node_attribs]) {
         return wantarray ? @{$self->[node_attribs]} : $self->[node_attribs];
     }
+
     return wantarray ? () : [];
 }
 
@@ -229,8 +233,7 @@ sub appendAttribute {
 }
 
 sub removeAttribute {
-    my $self = shift;
-    my $attrib = shift;
+    my ($self, $attrib) = @_;
 
     if (!ref($attrib)) {
         $attrib = $self->getAttributeNode($attrib);
@@ -248,8 +251,7 @@ sub removeAttribute {
 }
 
 sub setAttribute {
-    my $self = shift;
-    my ($name, $value) = @_;
+    my ($self, $name, $value) = @_;
 
     if (my $attrib = $self->getAttributeNode($name)) {
         $attrib->setNodeValue($value);
@@ -267,8 +269,7 @@ sub setAttribute {
 }
 
 sub setAttributeNode {
-    my $self = shift;
-    my ($node) = @_;
+    my ($self, $node) = @_;
 
     if (my $attrib = $self->getAttributeNode($node->getName)) {
         $attrib->setNodeValue($node->getValue);
@@ -285,13 +286,14 @@ sub setAttributeNode {
 }
 
 sub getNamespace {
-    my $self = shift;
-    my ($prefix) = @_;
+    my ($self, $prefix) = @_;
+
     $prefix ||= $self->getPrefix || '#default';
     my $namespaces = $self->[node_namespaces] || [];
     foreach my $ns (@$namespaces) {
         return $ns if $ns->getPrefix eq $prefix;
     }
+
     my $parent = $self->getParentNode;
 
     return $parent->getNamespace($prefix) if $parent;
@@ -299,17 +301,19 @@ sub getNamespace {
 
 sub getNamespaces {
     my $self = shift;
+
     if ($self->[node_namespaces]) {
         return wantarray ? @{$self->[node_namespaces]} : $self->[node_namespaces];
     }
+
     return wantarray ? () : [];
 }
 
 sub getNamespaceNodes { goto &getNamespaces }
 
 sub appendNamespace {
-    my $self = shift;
-    my ($ns) = @_;
+    my ($self, $ns) = @_;
+
     push @{$self->[node_namespaces]}, $ns;
     $ns->setParentNode($self);
     $ns->set_pos($#{$self->[node_namespaces]});
@@ -327,8 +331,7 @@ sub getExpandedName {
 }
 
 sub _to_sax {
-    my $self = shift;
-    my ($doch, $dtdh, $enth) = @_;
+    my ($self, $doch, $dtdh, $enth) = @_;
 
     my $tag = $self->getName;
     my @attr;
@@ -340,21 +343,21 @@ sub _to_sax {
     my $ns = $self->getNamespace($self->[node_prefix]);
     if ($ns) {
         $doch->start_element(
-                {
+            {
                 Name => $tag,
                 Attributes => { @attr },
                 NamespaceURI => $ns->getExpanded,
                 Prefix => $ns->getPrefix,
                 LocalName => $self->getLocalName,
-                }
+            }
             );
     }
     else {
         $doch->start_element(
-                {
+            {
                 Name => $tag,
                 Attributes => { @attr },
-                }
+            }
             );
     }
 
@@ -379,6 +382,7 @@ sub _to_sax {
 
 sub string_value {
     my $self = shift;
+
     my $string = '';
     foreach my $kid (@{$self->[node_children]}) {
         if ($kid->getNodeType == ELEMENT_NODE
@@ -386,28 +390,28 @@ sub string_value {
             $string .= $kid->string_value;
         }
     }
+
     return $string;
 }
 
 sub toString {
-    my $self = shift;
-    my $norecurse = shift;
+    my ($self, $norecurse) = @_;
+
     my $string = '';
     if (! $self->[node_name] ) {
-            # root node
-            return join('', map { $_->toString($norecurse) } @{$self->[node_children]});
+        # root node
+        return join('', map { $_->toString($norecurse) } @{$self->[node_children]});
     }
+
     $string .= "<" . $self->[node_name];
-
-        $string .= join('', map { $_->toString } @{$self->[node_namespaces]});
-
-        $string .= join('', map { $_->toString } @{$self->[node_attribs]});
+    $string .= join('', map { $_->toString } @{$self->[node_namespaces]});
+    $string .= join('', map { $_->toString } @{$self->[node_attribs]});
 
     if (@{$self->[node_children]}) {
         $string .= ">";
 
         if (!$norecurse) {
-                        $string .= join('', map { $_->toString($norecurse) } @{$self->[node_children]});
+            $string .= join('', map { $_->toString($norecurse) } @{$self->[node_children]});
         }
 
         $string .= "</" . $self->[node_name] . ">";
@@ -431,7 +435,7 @@ Element - an <element>
 =head2 new ( name, prefix )
 
 Create a new Element node with name "name" and prefix "prefix". The name
-be "prefix:local" if prefix is defined. I know that sounds wierd, but it
+be "prefix:local" if prefix is defined. I know that sounds weird, but it
 works ;-)
 
 =head2 getName
